.. _networkx_2.7.1:

NetworkX 2.7.1
==============

Release date: 5 March 2022

Supports Python 3.8, 3.9, and 3.10

Minor bug fixes.

Merged PRs
----------

A total of 7 changes have been committed.

- Designate 2.7 release
- Bump release version
- Fix release notes
- Change dev version to 2.7.1
- Fix line graph construction for heterogeneous nodes (#5357)
- Fix development banner (#5370)
- Simplify DelayedImportErrorModule (#5371)
- [nx_pylab] fix StopIteration, if empty dict is passed for labels. (#5372)

Contributors
------------

- Jarrod Millman
- Martin K. Scherer
- Stefan van der Walt
- jkudla
